@@ -1,2 +1,10 @@
+import os
+import glob
+
+from .loramon import *
+
 modules = glob.glob(os.path.dirname(__file__)+"/*.py")
-__all__ = [ os.path.basename(f)[:-3] for f in modules if not f.endswith('__init__.py')]
\ No newline at end of file
+__all__ = [ os.path.basename(f)[:-3] for f in modules if not f.endswith('__init__.py')]
+
+print(modules)
+print(__all__)
\ No newline at end of file
